@@ -5,9 +5,11 @@ frag.diameters <- function(graph, cumulative=FALSE)
   if( ! is.igraph(graph)) stop("Not a graph object")
   if( ! is.null(graph_attr(graph, "frag_type")) ) {
     if(graph_attr(graph, "frag_type") == "connection and similarity"){
-      warning("Diameter distribution is meaningless for 'connection and similarity' graph type")
+      warning("Diameter distribution is meaningless for 'connection and similarity' fragmentation graphs")
     }
   }
+  if(! is.logical(cumulative)) stop("The 'cumulative' parameter must be logical.")
+  
   g.list <- decompose(graph)
   diameter.v <- sapply(g.list, diameter, weights=NA, directed=FALSE, unconnected=FALSE)
   diameter.v <- hist(diameter.v, breaks=0:max(diameter.v), plot=FALSE)$count 
